from setuptools import setup, find_packages

setup(
    name='gologin',
    version='0.1',
    packages=find_packages(),
    install_requires=[
        # Deps
    ],
    author='GoLogin',
    author_email='yuri@gologin.com',
    description='Official GoLogin python package',
    url='https://github.com/gologinapp/pygologin',
)
